/****************************************************************************
** Meta object code from reading C++ file 'platformtheme.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../kirigami2-5.116.0/src/libkirigami/platformtheme.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'platformtheme.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kirigami__PlatformTheme_t {
    QByteArrayData data[57];
    char stringdata0[810];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kirigami__PlatformTheme_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kirigami__PlatformTheme_t qt_meta_stringdata_Kirigami__PlatformTheme = {
    {
QT_MOC_LITERAL(0, 0, 23), // "Kirigami::PlatformTheme"
QT_MOC_LITERAL(1, 24, 13), // "colorsChanged"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 18), // "defaultFontChanged"
QT_MOC_LITERAL(4, 58, 4), // "font"
QT_MOC_LITERAL(5, 63, 16), // "smallFontChanged"
QT_MOC_LITERAL(6, 80, 15), // "colorSetChanged"
QT_MOC_LITERAL(7, 96, 33), // "Kirigami::PlatformTheme::Colo..."
QT_MOC_LITERAL(8, 130, 8), // "colorSet"
QT_MOC_LITERAL(9, 139, 17), // "colorGroupChanged"
QT_MOC_LITERAL(10, 157, 35), // "Kirigami::PlatformTheme::Colo..."
QT_MOC_LITERAL(11, 193, 10), // "colorGroup"
QT_MOC_LITERAL(12, 204, 14), // "paletteChanged"
QT_MOC_LITERAL(13, 219, 3), // "pal"
QT_MOC_LITERAL(14, 223, 14), // "inheritChanged"
QT_MOC_LITERAL(15, 238, 7), // "inherit"
QT_MOC_LITERAL(16, 246, 13), // "iconFromTheme"
QT_MOC_LITERAL(17, 260, 4), // "name"
QT_MOC_LITERAL(18, 265, 11), // "customColor"
QT_MOC_LITERAL(19, 277, 8), // "ColorSet"
QT_MOC_LITERAL(20, 286, 10), // "ColorGroup"
QT_MOC_LITERAL(21, 297, 9), // "textColor"
QT_MOC_LITERAL(22, 307, 17), // "disabledTextColor"
QT_MOC_LITERAL(23, 325, 20), // "highlightedTextColor"
QT_MOC_LITERAL(24, 346, 15), // "activeTextColor"
QT_MOC_LITERAL(25, 362, 9), // "linkColor"
QT_MOC_LITERAL(26, 372, 16), // "visitedLinkColor"
QT_MOC_LITERAL(27, 389, 17), // "negativeTextColor"
QT_MOC_LITERAL(28, 407, 16), // "neutralTextColor"
QT_MOC_LITERAL(29, 424, 17), // "positiveTextColor"
QT_MOC_LITERAL(30, 442, 15), // "backgroundColor"
QT_MOC_LITERAL(31, 458, 24), // "alternateBackgroundColor"
QT_MOC_LITERAL(32, 483, 14), // "highlightColor"
QT_MOC_LITERAL(33, 498, 21), // "activeBackgroundColor"
QT_MOC_LITERAL(34, 520, 19), // "linkBackgroundColor"
QT_MOC_LITERAL(35, 540, 26), // "visitedLinkBackgroundColor"
QT_MOC_LITERAL(36, 567, 23), // "negativeBackgroundColor"
QT_MOC_LITERAL(37, 591, 22), // "neutralBackgroundColor"
QT_MOC_LITERAL(38, 614, 23), // "positiveBackgroundColor"
QT_MOC_LITERAL(39, 638, 10), // "focusColor"
QT_MOC_LITERAL(40, 649, 10), // "hoverColor"
QT_MOC_LITERAL(41, 660, 11), // "defaultFont"
QT_MOC_LITERAL(42, 672, 9), // "smallFont"
QT_MOC_LITERAL(43, 682, 7), // "palette"
QT_MOC_LITERAL(44, 690, 4), // "View"
QT_MOC_LITERAL(45, 695, 6), // "Window"
QT_MOC_LITERAL(46, 702, 6), // "Button"
QT_MOC_LITERAL(47, 709, 9), // "Selection"
QT_MOC_LITERAL(48, 719, 7), // "Tooltip"
QT_MOC_LITERAL(49, 727, 13), // "Complementary"
QT_MOC_LITERAL(50, 741, 6), // "Header"
QT_MOC_LITERAL(51, 748, 13), // "ColorSetCount"
QT_MOC_LITERAL(52, 762, 8), // "Disabled"
QT_MOC_LITERAL(53, 771, 6), // "Active"
QT_MOC_LITERAL(54, 778, 8), // "Inactive"
QT_MOC_LITERAL(55, 787, 6), // "Normal"
QT_MOC_LITERAL(56, 794, 15) // "ColorGroupCount"

    },
    "Kirigami::PlatformTheme\0colorsChanged\0"
    "\0defaultFontChanged\0font\0smallFontChanged\0"
    "colorSetChanged\0Kirigami::PlatformTheme::ColorSet\0"
    "colorSet\0colorGroupChanged\0"
    "Kirigami::PlatformTheme::ColorGroup\0"
    "colorGroup\0paletteChanged\0pal\0"
    "inheritChanged\0inherit\0iconFromTheme\0"
    "name\0customColor\0ColorSet\0ColorGroup\0"
    "textColor\0disabledTextColor\0"
    "highlightedTextColor\0activeTextColor\0"
    "linkColor\0visitedLinkColor\0negativeTextColor\0"
    "neutralTextColor\0positiveTextColor\0"
    "backgroundColor\0alternateBackgroundColor\0"
    "highlightColor\0activeBackgroundColor\0"
    "linkBackgroundColor\0visitedLinkBackgroundColor\0"
    "negativeBackgroundColor\0neutralBackgroundColor\0"
    "positiveBackgroundColor\0focusColor\0"
    "hoverColor\0defaultFont\0smallFont\0"
    "palette\0View\0Window\0Button\0Selection\0"
    "Tooltip\0Complementary\0Header\0ColorSetCount\0"
    "Disabled\0Active\0Inactive\0Normal\0"
    "ColorGroupCount"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kirigami__PlatformTheme[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
      26,   86, // properties
       2,  190, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x06 /* Public */,
       3,    1,   60,    2, 0x06 /* Public */,
       5,    1,   63,    2, 0x06 /* Public */,
       6,    1,   66,    2, 0x06 /* Public */,
       9,    1,   69,    2, 0x06 /* Public */,
      12,    1,   72,    2, 0x06 /* Public */,
      14,    1,   75,    2, 0x06 /* Public */,

 // methods: name, argc, parameters, tag, flags
      16,    2,   78,    2, 0x02 /* Public */,
      16,    1,   83,    2, 0x22 /* Public | MethodCloned */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QFont,    4,
    QMetaType::Void, QMetaType::QFont,    4,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, QMetaType::QPalette,   13,
    QMetaType::Void, QMetaType::Bool,   15,

 // methods: parameters
    QMetaType::QIcon, QMetaType::QString, QMetaType::QColor,   17,   18,
    QMetaType::QIcon, QMetaType::QString,   17,

 // properties: name, type, flags
       8, 0x80000000 | 19, 0x0049510b,
      11, 0x80000000 | 20, 0x0049510b,
      15, QMetaType::Bool, 0x00495103,
      21, QMetaType::QColor, 0x00495007,
      22, QMetaType::QColor, 0x00495007,
      23, QMetaType::QColor, 0x00495007,
      24, QMetaType::QColor, 0x00495007,
      25, QMetaType::QColor, 0x00495007,
      26, QMetaType::QColor, 0x00495007,
      27, QMetaType::QColor, 0x00495007,
      28, QMetaType::QColor, 0x00495007,
      29, QMetaType::QColor, 0x00495007,
      30, QMetaType::QColor, 0x00495007,
      31, QMetaType::QColor, 0x00495007,
      32, QMetaType::QColor, 0x00495007,
      33, QMetaType::QColor, 0x00495007,
      34, QMetaType::QColor, 0x00495007,
      35, QMetaType::QColor, 0x00495007,
      36, QMetaType::QColor, 0x00495007,
      37, QMetaType::QColor, 0x00495007,
      38, QMetaType::QColor, 0x00495007,
      39, QMetaType::QColor, 0x00495007,
      40, QMetaType::QColor, 0x00495007,
      41, QMetaType::QFont, 0x00495001,
      42, QMetaType::QFont, 0x00495001,
      43, QMetaType::QPalette, 0x00495001,

 // properties: notify_signal_id
       3,
       4,
       6,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       1,
       1,
       5,

 // enums: name, alias, flags, count, data
      19,   19, 0x0,    8,  200,
      20,   20, 0x0,    5,  216,

 // enum data: key, value
      44, uint(Kirigami::PlatformTheme::View),
      45, uint(Kirigami::PlatformTheme::Window),
      46, uint(Kirigami::PlatformTheme::Button),
      47, uint(Kirigami::PlatformTheme::Selection),
      48, uint(Kirigami::PlatformTheme::Tooltip),
      49, uint(Kirigami::PlatformTheme::Complementary),
      50, uint(Kirigami::PlatformTheme::Header),
      51, uint(Kirigami::PlatformTheme::ColorSetCount),
      52, uint(Kirigami::PlatformTheme::Disabled),
      53, uint(Kirigami::PlatformTheme::Active),
      54, uint(Kirigami::PlatformTheme::Inactive),
      55, uint(Kirigami::PlatformTheme::Normal),
      56, uint(Kirigami::PlatformTheme::ColorGroupCount),

       0        // eod
};

void Kirigami::PlatformTheme::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<PlatformTheme *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->colorsChanged(); break;
        case 1: _t->defaultFontChanged((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 2: _t->smallFontChanged((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 3: _t->colorSetChanged((*reinterpret_cast< Kirigami::PlatformTheme::ColorSet(*)>(_a[1]))); break;
        case 4: _t->colorGroupChanged((*reinterpret_cast< Kirigami::PlatformTheme::ColorGroup(*)>(_a[1]))); break;
        case 5: _t->paletteChanged((*reinterpret_cast< const QPalette(*)>(_a[1]))); break;
        case 6: _t->inheritChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: { QIcon _r = _t->iconFromTheme((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QColor(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QIcon*>(_a[0]) = std::move(_r); }  break;
        case 8: { QIcon _r = _t->iconFromTheme((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QIcon*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (PlatformTheme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlatformTheme::colorsChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (PlatformTheme::*)(const QFont & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlatformTheme::defaultFontChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (PlatformTheme::*)(const QFont & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlatformTheme::smallFontChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (PlatformTheme::*)(Kirigami::PlatformTheme::ColorSet );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlatformTheme::colorSetChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (PlatformTheme::*)(Kirigami::PlatformTheme::ColorGroup );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlatformTheme::colorGroupChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (PlatformTheme::*)(const QPalette & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlatformTheme::paletteChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (PlatformTheme::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlatformTheme::inheritChanged)) {
                *result = 6;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<PlatformTheme *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< ColorSet*>(_v) = _t->colorSet(); break;
        case 1: *reinterpret_cast< ColorGroup*>(_v) = _t->colorGroup(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->inherit(); break;
        case 3: *reinterpret_cast< QColor*>(_v) = _t->textColor(); break;
        case 4: *reinterpret_cast< QColor*>(_v) = _t->disabledTextColor(); break;
        case 5: *reinterpret_cast< QColor*>(_v) = _t->highlightedTextColor(); break;
        case 6: *reinterpret_cast< QColor*>(_v) = _t->activeTextColor(); break;
        case 7: *reinterpret_cast< QColor*>(_v) = _t->linkColor(); break;
        case 8: *reinterpret_cast< QColor*>(_v) = _t->visitedLinkColor(); break;
        case 9: *reinterpret_cast< QColor*>(_v) = _t->negativeTextColor(); break;
        case 10: *reinterpret_cast< QColor*>(_v) = _t->neutralTextColor(); break;
        case 11: *reinterpret_cast< QColor*>(_v) = _t->positiveTextColor(); break;
        case 12: *reinterpret_cast< QColor*>(_v) = _t->backgroundColor(); break;
        case 13: *reinterpret_cast< QColor*>(_v) = _t->alternateBackgroundColor(); break;
        case 14: *reinterpret_cast< QColor*>(_v) = _t->highlightColor(); break;
        case 15: *reinterpret_cast< QColor*>(_v) = _t->activeBackgroundColor(); break;
        case 16: *reinterpret_cast< QColor*>(_v) = _t->linkBackgroundColor(); break;
        case 17: *reinterpret_cast< QColor*>(_v) = _t->visitedLinkBackgroundColor(); break;
        case 18: *reinterpret_cast< QColor*>(_v) = _t->negativeBackgroundColor(); break;
        case 19: *reinterpret_cast< QColor*>(_v) = _t->neutralBackgroundColor(); break;
        case 20: *reinterpret_cast< QColor*>(_v) = _t->positiveBackgroundColor(); break;
        case 21: *reinterpret_cast< QColor*>(_v) = _t->focusColor(); break;
        case 22: *reinterpret_cast< QColor*>(_v) = _t->hoverColor(); break;
        case 23: *reinterpret_cast< QFont*>(_v) = _t->defaultFont(); break;
        case 24: *reinterpret_cast< QFont*>(_v) = _t->smallFont(); break;
        case 25: *reinterpret_cast< QPalette*>(_v) = _t->palette(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<PlatformTheme *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setColorSet(*reinterpret_cast< ColorSet*>(_v)); break;
        case 1: _t->setColorGroup(*reinterpret_cast< ColorGroup*>(_v)); break;
        case 2: _t->setInherit(*reinterpret_cast< bool*>(_v)); break;
        case 3: _t->setCustomTextColor(*reinterpret_cast< QColor*>(_v)); break;
        case 4: _t->setCustomDisabledTextColor(*reinterpret_cast< QColor*>(_v)); break;
        case 5: _t->setCustomHighlightedTextColor(*reinterpret_cast< QColor*>(_v)); break;
        case 6: _t->setCustomActiveTextColor(*reinterpret_cast< QColor*>(_v)); break;
        case 7: _t->setCustomLinkColor(*reinterpret_cast< QColor*>(_v)); break;
        case 8: _t->setCustomVisitedLinkColor(*reinterpret_cast< QColor*>(_v)); break;
        case 9: _t->setCustomNegativeTextColor(*reinterpret_cast< QColor*>(_v)); break;
        case 10: _t->setCustomNeutralTextColor(*reinterpret_cast< QColor*>(_v)); break;
        case 11: _t->setCustomPositiveTextColor(*reinterpret_cast< QColor*>(_v)); break;
        case 12: _t->setCustomBackgroundColor(*reinterpret_cast< QColor*>(_v)); break;
        case 13: _t->setCustomAlternateBackgroundColor(*reinterpret_cast< QColor*>(_v)); break;
        case 14: _t->setCustomHighlightColor(*reinterpret_cast< QColor*>(_v)); break;
        case 15: _t->setCustomActiveBackgroundColor(*reinterpret_cast< QColor*>(_v)); break;
        case 16: _t->setCustomLinkBackgroundColor(*reinterpret_cast< QColor*>(_v)); break;
        case 17: _t->setCustomVisitedLinkBackgroundColor(*reinterpret_cast< QColor*>(_v)); break;
        case 18: _t->setCustomNegativeBackgroundColor(*reinterpret_cast< QColor*>(_v)); break;
        case 19: _t->setCustomNeutralBackgroundColor(*reinterpret_cast< QColor*>(_v)); break;
        case 20: _t->setCustomPositiveBackgroundColor(*reinterpret_cast< QColor*>(_v)); break;
        case 21: _t->setCustomFocusColor(*reinterpret_cast< QColor*>(_v)); break;
        case 22: _t->setCustomHoverColor(*reinterpret_cast< QColor*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
        PlatformTheme *_t = static_cast<PlatformTheme *>(_o);
        (void)_t;
        switch (_id) {
        case 3: _t->setCustomTextColor(); break;
        case 4: _t->setCustomDisabledTextColor(); break;
        case 5: _t->setCustomHighlightedTextColor(); break;
        case 6: _t->setCustomActiveTextColor(); break;
        case 7: _t->setCustomLinkColor(); break;
        case 8: _t->setCustomVisitedLinkColor(); break;
        case 9: _t->setCustomNegativeTextColor(); break;
        case 10: _t->setCustomNeutralTextColor(); break;
        case 11: _t->setCustomPositiveTextColor(); break;
        case 12: _t->setCustomBackgroundColor(); break;
        case 13: _t->setCustomAlternateBackgroundColor(); break;
        case 14: _t->setCustomHighlightColor(); break;
        case 15: _t->setCustomActiveBackgroundColor(); break;
        case 16: _t->setCustomLinkBackgroundColor(); break;
        case 17: _t->setCustomVisitedLinkBackgroundColor(); break;
        case 18: _t->setCustomNegativeBackgroundColor(); break;
        case 19: _t->setCustomNeutralBackgroundColor(); break;
        case 20: _t->setCustomPositiveBackgroundColor(); break;
        case 21: _t->setCustomFocusColor(); break;
        case 22: _t->setCustomHoverColor(); break;
        default: break;
        }
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Kirigami::PlatformTheme::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Kirigami__PlatformTheme.data,
    qt_meta_data_Kirigami__PlatformTheme,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Kirigami::PlatformTheme::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kirigami::PlatformTheme::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kirigami__PlatformTheme.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kirigami::PlatformTheme::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 26;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 26;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 26;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 26;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 26;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Kirigami::PlatformTheme::colorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Kirigami::PlatformTheme::defaultFontChanged(const QFont & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Kirigami::PlatformTheme::smallFontChanged(const QFont & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Kirigami::PlatformTheme::colorSetChanged(Kirigami::PlatformTheme::ColorSet _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Kirigami::PlatformTheme::colorGroupChanged(Kirigami::PlatformTheme::ColorGroup _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Kirigami::PlatformTheme::paletteChanged(const QPalette & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Kirigami::PlatformTheme::inheritChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
