/****************************************************************************
** Meta object code from reading C++ file 'basictheme_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../kirigami2-5.116.0/src/libkirigami/basictheme_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'basictheme_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kirigami__BasicThemeDefinition_t {
    QByteArrayData data[58];
    char stringdata0[1112];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kirigami__BasicThemeDefinition_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kirigami__BasicThemeDefinition_t qt_meta_stringdata_Kirigami__BasicThemeDefinition = {
    {
QT_MOC_LITERAL(0, 0, 30), // "Kirigami::BasicThemeDefinition"
QT_MOC_LITERAL(1, 31, 7), // "changed"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 4), // "sync"
QT_MOC_LITERAL(4, 45, 11), // "QQuickItem*"
QT_MOC_LITERAL(5, 57, 6), // "object"
QT_MOC_LITERAL(6, 64, 9), // "textColor"
QT_MOC_LITERAL(7, 74, 17), // "disabledTextColor"
QT_MOC_LITERAL(8, 92, 14), // "highlightColor"
QT_MOC_LITERAL(9, 107, 20), // "highlightedTextColor"
QT_MOC_LITERAL(10, 128, 15), // "backgroundColor"
QT_MOC_LITERAL(11, 144, 24), // "alternateBackgroundColor"
QT_MOC_LITERAL(12, 169, 10), // "focusColor"
QT_MOC_LITERAL(13, 180, 10), // "hoverColor"
QT_MOC_LITERAL(14, 191, 15), // "activeTextColor"
QT_MOC_LITERAL(15, 207, 21), // "activeBackgroundColor"
QT_MOC_LITERAL(16, 229, 9), // "linkColor"
QT_MOC_LITERAL(17, 239, 19), // "linkBackgroundColor"
QT_MOC_LITERAL(18, 259, 16), // "visitedLinkColor"
QT_MOC_LITERAL(19, 276, 26), // "visitedLinkBackgroundColor"
QT_MOC_LITERAL(20, 303, 17), // "negativeTextColor"
QT_MOC_LITERAL(21, 321, 23), // "negativeBackgroundColor"
QT_MOC_LITERAL(22, 345, 16), // "neutralTextColor"
QT_MOC_LITERAL(23, 362, 22), // "neutralBackgroundColor"
QT_MOC_LITERAL(24, 385, 17), // "positiveTextColor"
QT_MOC_LITERAL(25, 403, 23), // "positiveBackgroundColor"
QT_MOC_LITERAL(26, 427, 15), // "buttonTextColor"
QT_MOC_LITERAL(27, 443, 21), // "buttonBackgroundColor"
QT_MOC_LITERAL(28, 465, 30), // "buttonAlternateBackgroundColor"
QT_MOC_LITERAL(29, 496, 16), // "buttonHoverColor"
QT_MOC_LITERAL(30, 513, 16), // "buttonFocusColor"
QT_MOC_LITERAL(31, 530, 13), // "viewTextColor"
QT_MOC_LITERAL(32, 544, 19), // "viewBackgroundColor"
QT_MOC_LITERAL(33, 564, 28), // "viewAlternateBackgroundColor"
QT_MOC_LITERAL(34, 593, 14), // "viewHoverColor"
QT_MOC_LITERAL(35, 608, 14), // "viewFocusColor"
QT_MOC_LITERAL(36, 623, 18), // "selectionTextColor"
QT_MOC_LITERAL(37, 642, 24), // "selectionBackgroundColor"
QT_MOC_LITERAL(38, 667, 33), // "selectionAlternateBackgroundC..."
QT_MOC_LITERAL(39, 701, 19), // "selectionHoverColor"
QT_MOC_LITERAL(40, 721, 19), // "selectionFocusColor"
QT_MOC_LITERAL(41, 741, 16), // "tooltipTextColor"
QT_MOC_LITERAL(42, 758, 22), // "tooltipBackgroundColor"
QT_MOC_LITERAL(43, 781, 31), // "tooltipAlternateBackgroundColor"
QT_MOC_LITERAL(44, 813, 17), // "tooltipHoverColor"
QT_MOC_LITERAL(45, 831, 17), // "tooltipFocusColor"
QT_MOC_LITERAL(46, 849, 22), // "complementaryTextColor"
QT_MOC_LITERAL(47, 872, 28), // "complementaryBackgroundColor"
QT_MOC_LITERAL(48, 901, 37), // "complementaryAlternateBackgro..."
QT_MOC_LITERAL(49, 939, 23), // "complementaryHoverColor"
QT_MOC_LITERAL(50, 963, 23), // "complementaryFocusColor"
QT_MOC_LITERAL(51, 987, 15), // "headerTextColor"
QT_MOC_LITERAL(52, 1003, 21), // "headerBackgroundColor"
QT_MOC_LITERAL(53, 1025, 30), // "headerAlternateBackgroundColor"
QT_MOC_LITERAL(54, 1056, 16), // "headerHoverColor"
QT_MOC_LITERAL(55, 1073, 16), // "headerFocusColor"
QT_MOC_LITERAL(56, 1090, 11), // "defaultFont"
QT_MOC_LITERAL(57, 1102, 9) // "smallFont"

    },
    "Kirigami::BasicThemeDefinition\0changed\0"
    "\0sync\0QQuickItem*\0object\0textColor\0"
    "disabledTextColor\0highlightColor\0"
    "highlightedTextColor\0backgroundColor\0"
    "alternateBackgroundColor\0focusColor\0"
    "hoverColor\0activeTextColor\0"
    "activeBackgroundColor\0linkColor\0"
    "linkBackgroundColor\0visitedLinkColor\0"
    "visitedLinkBackgroundColor\0negativeTextColor\0"
    "negativeBackgroundColor\0neutralTextColor\0"
    "neutralBackgroundColor\0positiveTextColor\0"
    "positiveBackgroundColor\0buttonTextColor\0"
    "buttonBackgroundColor\0"
    "buttonAlternateBackgroundColor\0"
    "buttonHoverColor\0buttonFocusColor\0"
    "viewTextColor\0viewBackgroundColor\0"
    "viewAlternateBackgroundColor\0"
    "viewHoverColor\0viewFocusColor\0"
    "selectionTextColor\0selectionBackgroundColor\0"
    "selectionAlternateBackgroundColor\0"
    "selectionHoverColor\0selectionFocusColor\0"
    "tooltipTextColor\0tooltipBackgroundColor\0"
    "tooltipAlternateBackgroundColor\0"
    "tooltipHoverColor\0tooltipFocusColor\0"
    "complementaryTextColor\0"
    "complementaryBackgroundColor\0"
    "complementaryAlternateBackgroundColor\0"
    "complementaryHoverColor\0complementaryFocusColor\0"
    "headerTextColor\0headerBackgroundColor\0"
    "headerAlternateBackgroundColor\0"
    "headerHoverColor\0headerFocusColor\0"
    "defaultFont\0smallFont"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kirigami__BasicThemeDefinition[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
      52,   28, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x06 /* Public */,
       3,    1,   25,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    5,

 // properties: name, type, flags
       6, QMetaType::QColor, 0x00495003,
       7, QMetaType::QColor, 0x00495003,
       8, QMetaType::QColor, 0x00495003,
       9, QMetaType::QColor, 0x00495003,
      10, QMetaType::QColor, 0x00495003,
      11, QMetaType::QColor, 0x00495003,
      12, QMetaType::QColor, 0x00495003,
      13, QMetaType::QColor, 0x00495003,
      14, QMetaType::QColor, 0x00495003,
      15, QMetaType::QColor, 0x00495003,
      16, QMetaType::QColor, 0x00495003,
      17, QMetaType::QColor, 0x00495003,
      18, QMetaType::QColor, 0x00495003,
      19, QMetaType::QColor, 0x00495003,
      20, QMetaType::QColor, 0x00495003,
      21, QMetaType::QColor, 0x00495003,
      22, QMetaType::QColor, 0x00495003,
      23, QMetaType::QColor, 0x00495003,
      24, QMetaType::QColor, 0x00495003,
      25, QMetaType::QColor, 0x00495003,
      26, QMetaType::QColor, 0x00495003,
      27, QMetaType::QColor, 0x00495003,
      28, QMetaType::QColor, 0x00495003,
      29, QMetaType::QColor, 0x00495003,
      30, QMetaType::QColor, 0x00495003,
      31, QMetaType::QColor, 0x00495003,
      32, QMetaType::QColor, 0x00495003,
      33, QMetaType::QColor, 0x00495003,
      34, QMetaType::QColor, 0x00495003,
      35, QMetaType::QColor, 0x00495003,
      36, QMetaType::QColor, 0x00495003,
      37, QMetaType::QColor, 0x00495003,
      38, QMetaType::QColor, 0x00495003,
      39, QMetaType::QColor, 0x00495003,
      40, QMetaType::QColor, 0x00495003,
      41, QMetaType::QColor, 0x00495003,
      42, QMetaType::QColor, 0x00495003,
      43, QMetaType::QColor, 0x00495003,
      44, QMetaType::QColor, 0x00495003,
      45, QMetaType::QColor, 0x00495003,
      46, QMetaType::QColor, 0x00495003,
      47, QMetaType::QColor, 0x00495003,
      48, QMetaType::QColor, 0x00495003,
      49, QMetaType::QColor, 0x00495003,
      50, QMetaType::QColor, 0x00495003,
      51, QMetaType::QColor, 0x00495003,
      52, QMetaType::QColor, 0x00495003,
      53, QMetaType::QColor, 0x00495003,
      54, QMetaType::QColor, 0x00495003,
      55, QMetaType::QColor, 0x00495003,
      56, QMetaType::QFont, 0x00495003,
      57, QMetaType::QFont, 0x00495003,

 // properties: notify_signal_id
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,

       0        // eod
};

void Kirigami::BasicThemeDefinition::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BasicThemeDefinition *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->sync((*reinterpret_cast< QQuickItem*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (BasicThemeDefinition::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BasicThemeDefinition::changed)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (BasicThemeDefinition::*)(QQuickItem * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BasicThemeDefinition::sync)) {
                *result = 1;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<BasicThemeDefinition *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QColor*>(_v) = _t->textColor; break;
        case 1: *reinterpret_cast< QColor*>(_v) = _t->disabledTextColor; break;
        case 2: *reinterpret_cast< QColor*>(_v) = _t->highlightColor; break;
        case 3: *reinterpret_cast< QColor*>(_v) = _t->highlightedTextColor; break;
        case 4: *reinterpret_cast< QColor*>(_v) = _t->backgroundColor; break;
        case 5: *reinterpret_cast< QColor*>(_v) = _t->alternateBackgroundColor; break;
        case 6: *reinterpret_cast< QColor*>(_v) = _t->focusColor; break;
        case 7: *reinterpret_cast< QColor*>(_v) = _t->hoverColor; break;
        case 8: *reinterpret_cast< QColor*>(_v) = _t->activeTextColor; break;
        case 9: *reinterpret_cast< QColor*>(_v) = _t->activeBackgroundColor; break;
        case 10: *reinterpret_cast< QColor*>(_v) = _t->linkColor; break;
        case 11: *reinterpret_cast< QColor*>(_v) = _t->linkBackgroundColor; break;
        case 12: *reinterpret_cast< QColor*>(_v) = _t->visitedLinkColor; break;
        case 13: *reinterpret_cast< QColor*>(_v) = _t->visitedLinkBackgroundColor; break;
        case 14: *reinterpret_cast< QColor*>(_v) = _t->negativeTextColor; break;
        case 15: *reinterpret_cast< QColor*>(_v) = _t->negativeBackgroundColor; break;
        case 16: *reinterpret_cast< QColor*>(_v) = _t->neutralTextColor; break;
        case 17: *reinterpret_cast< QColor*>(_v) = _t->neutralBackgroundColor; break;
        case 18: *reinterpret_cast< QColor*>(_v) = _t->positiveTextColor; break;
        case 19: *reinterpret_cast< QColor*>(_v) = _t->positiveBackgroundColor; break;
        case 20: *reinterpret_cast< QColor*>(_v) = _t->buttonTextColor; break;
        case 21: *reinterpret_cast< QColor*>(_v) = _t->buttonBackgroundColor; break;
        case 22: *reinterpret_cast< QColor*>(_v) = _t->buttonAlternateBackgroundColor; break;
        case 23: *reinterpret_cast< QColor*>(_v) = _t->buttonHoverColor; break;
        case 24: *reinterpret_cast< QColor*>(_v) = _t->buttonFocusColor; break;
        case 25: *reinterpret_cast< QColor*>(_v) = _t->viewTextColor; break;
        case 26: *reinterpret_cast< QColor*>(_v) = _t->viewBackgroundColor; break;
        case 27: *reinterpret_cast< QColor*>(_v) = _t->viewAlternateBackgroundColor; break;
        case 28: *reinterpret_cast< QColor*>(_v) = _t->viewHoverColor; break;
        case 29: *reinterpret_cast< QColor*>(_v) = _t->viewFocusColor; break;
        case 30: *reinterpret_cast< QColor*>(_v) = _t->selectionTextColor; break;
        case 31: *reinterpret_cast< QColor*>(_v) = _t->selectionBackgroundColor; break;
        case 32: *reinterpret_cast< QColor*>(_v) = _t->selectionAlternateBackgroundColor; break;
        case 33: *reinterpret_cast< QColor*>(_v) = _t->selectionHoverColor; break;
        case 34: *reinterpret_cast< QColor*>(_v) = _t->selectionFocusColor; break;
        case 35: *reinterpret_cast< QColor*>(_v) = _t->tooltipTextColor; break;
        case 36: *reinterpret_cast< QColor*>(_v) = _t->tooltipBackgroundColor; break;
        case 37: *reinterpret_cast< QColor*>(_v) = _t->tooltipAlternateBackgroundColor; break;
        case 38: *reinterpret_cast< QColor*>(_v) = _t->tooltipHoverColor; break;
        case 39: *reinterpret_cast< QColor*>(_v) = _t->tooltipFocusColor; break;
        case 40: *reinterpret_cast< QColor*>(_v) = _t->complementaryTextColor; break;
        case 41: *reinterpret_cast< QColor*>(_v) = _t->complementaryBackgroundColor; break;
        case 42: *reinterpret_cast< QColor*>(_v) = _t->complementaryAlternateBackgroundColor; break;
        case 43: *reinterpret_cast< QColor*>(_v) = _t->complementaryHoverColor; break;
        case 44: *reinterpret_cast< QColor*>(_v) = _t->complementaryFocusColor; break;
        case 45: *reinterpret_cast< QColor*>(_v) = _t->headerTextColor; break;
        case 46: *reinterpret_cast< QColor*>(_v) = _t->headerBackgroundColor; break;
        case 47: *reinterpret_cast< QColor*>(_v) = _t->headerAlternateBackgroundColor; break;
        case 48: *reinterpret_cast< QColor*>(_v) = _t->headerHoverColor; break;
        case 49: *reinterpret_cast< QColor*>(_v) = _t->headerFocusColor; break;
        case 50: *reinterpret_cast< QFont*>(_v) = _t->defaultFont; break;
        case 51: *reinterpret_cast< QFont*>(_v) = _t->smallFont; break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<BasicThemeDefinition *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (_t->textColor != *reinterpret_cast< QColor*>(_v)) {
                _t->textColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 1:
            if (_t->disabledTextColor != *reinterpret_cast< QColor*>(_v)) {
                _t->disabledTextColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 2:
            if (_t->highlightColor != *reinterpret_cast< QColor*>(_v)) {
                _t->highlightColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 3:
            if (_t->highlightedTextColor != *reinterpret_cast< QColor*>(_v)) {
                _t->highlightedTextColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 4:
            if (_t->backgroundColor != *reinterpret_cast< QColor*>(_v)) {
                _t->backgroundColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 5:
            if (_t->alternateBackgroundColor != *reinterpret_cast< QColor*>(_v)) {
                _t->alternateBackgroundColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 6:
            if (_t->focusColor != *reinterpret_cast< QColor*>(_v)) {
                _t->focusColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 7:
            if (_t->hoverColor != *reinterpret_cast< QColor*>(_v)) {
                _t->hoverColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 8:
            if (_t->activeTextColor != *reinterpret_cast< QColor*>(_v)) {
                _t->activeTextColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 9:
            if (_t->activeBackgroundColor != *reinterpret_cast< QColor*>(_v)) {
                _t->activeBackgroundColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 10:
            if (_t->linkColor != *reinterpret_cast< QColor*>(_v)) {
                _t->linkColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 11:
            if (_t->linkBackgroundColor != *reinterpret_cast< QColor*>(_v)) {
                _t->linkBackgroundColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 12:
            if (_t->visitedLinkColor != *reinterpret_cast< QColor*>(_v)) {
                _t->visitedLinkColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 13:
            if (_t->visitedLinkBackgroundColor != *reinterpret_cast< QColor*>(_v)) {
                _t->visitedLinkBackgroundColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 14:
            if (_t->negativeTextColor != *reinterpret_cast< QColor*>(_v)) {
                _t->negativeTextColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 15:
            if (_t->negativeBackgroundColor != *reinterpret_cast< QColor*>(_v)) {
                _t->negativeBackgroundColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 16:
            if (_t->neutralTextColor != *reinterpret_cast< QColor*>(_v)) {
                _t->neutralTextColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 17:
            if (_t->neutralBackgroundColor != *reinterpret_cast< QColor*>(_v)) {
                _t->neutralBackgroundColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 18:
            if (_t->positiveTextColor != *reinterpret_cast< QColor*>(_v)) {
                _t->positiveTextColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 19:
            if (_t->positiveBackgroundColor != *reinterpret_cast< QColor*>(_v)) {
                _t->positiveBackgroundColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 20:
            if (_t->buttonTextColor != *reinterpret_cast< QColor*>(_v)) {
                _t->buttonTextColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 21:
            if (_t->buttonBackgroundColor != *reinterpret_cast< QColor*>(_v)) {
                _t->buttonBackgroundColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 22:
            if (_t->buttonAlternateBackgroundColor != *reinterpret_cast< QColor*>(_v)) {
                _t->buttonAlternateBackgroundColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 23:
            if (_t->buttonHoverColor != *reinterpret_cast< QColor*>(_v)) {
                _t->buttonHoverColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 24:
            if (_t->buttonFocusColor != *reinterpret_cast< QColor*>(_v)) {
                _t->buttonFocusColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 25:
            if (_t->viewTextColor != *reinterpret_cast< QColor*>(_v)) {
                _t->viewTextColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 26:
            if (_t->viewBackgroundColor != *reinterpret_cast< QColor*>(_v)) {
                _t->viewBackgroundColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 27:
            if (_t->viewAlternateBackgroundColor != *reinterpret_cast< QColor*>(_v)) {
                _t->viewAlternateBackgroundColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 28:
            if (_t->viewHoverColor != *reinterpret_cast< QColor*>(_v)) {
                _t->viewHoverColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 29:
            if (_t->viewFocusColor != *reinterpret_cast< QColor*>(_v)) {
                _t->viewFocusColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 30:
            if (_t->selectionTextColor != *reinterpret_cast< QColor*>(_v)) {
                _t->selectionTextColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 31:
            if (_t->selectionBackgroundColor != *reinterpret_cast< QColor*>(_v)) {
                _t->selectionBackgroundColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 32:
            if (_t->selectionAlternateBackgroundColor != *reinterpret_cast< QColor*>(_v)) {
                _t->selectionAlternateBackgroundColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 33:
            if (_t->selectionHoverColor != *reinterpret_cast< QColor*>(_v)) {
                _t->selectionHoverColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 34:
            if (_t->selectionFocusColor != *reinterpret_cast< QColor*>(_v)) {
                _t->selectionFocusColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 35:
            if (_t->tooltipTextColor != *reinterpret_cast< QColor*>(_v)) {
                _t->tooltipTextColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 36:
            if (_t->tooltipBackgroundColor != *reinterpret_cast< QColor*>(_v)) {
                _t->tooltipBackgroundColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 37:
            if (_t->tooltipAlternateBackgroundColor != *reinterpret_cast< QColor*>(_v)) {
                _t->tooltipAlternateBackgroundColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 38:
            if (_t->tooltipHoverColor != *reinterpret_cast< QColor*>(_v)) {
                _t->tooltipHoverColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 39:
            if (_t->tooltipFocusColor != *reinterpret_cast< QColor*>(_v)) {
                _t->tooltipFocusColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 40:
            if (_t->complementaryTextColor != *reinterpret_cast< QColor*>(_v)) {
                _t->complementaryTextColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 41:
            if (_t->complementaryBackgroundColor != *reinterpret_cast< QColor*>(_v)) {
                _t->complementaryBackgroundColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 42:
            if (_t->complementaryAlternateBackgroundColor != *reinterpret_cast< QColor*>(_v)) {
                _t->complementaryAlternateBackgroundColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 43:
            if (_t->complementaryHoverColor != *reinterpret_cast< QColor*>(_v)) {
                _t->complementaryHoverColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 44:
            if (_t->complementaryFocusColor != *reinterpret_cast< QColor*>(_v)) {
                _t->complementaryFocusColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 45:
            if (_t->headerTextColor != *reinterpret_cast< QColor*>(_v)) {
                _t->headerTextColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 46:
            if (_t->headerBackgroundColor != *reinterpret_cast< QColor*>(_v)) {
                _t->headerBackgroundColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 47:
            if (_t->headerAlternateBackgroundColor != *reinterpret_cast< QColor*>(_v)) {
                _t->headerAlternateBackgroundColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 48:
            if (_t->headerHoverColor != *reinterpret_cast< QColor*>(_v)) {
                _t->headerHoverColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 49:
            if (_t->headerFocusColor != *reinterpret_cast< QColor*>(_v)) {
                _t->headerFocusColor = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 50:
            if (_t->defaultFont != *reinterpret_cast< QFont*>(_v)) {
                _t->defaultFont = *reinterpret_cast< QFont*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        case 51:
            if (_t->smallFont != *reinterpret_cast< QFont*>(_v)) {
                _t->smallFont = *reinterpret_cast< QFont*>(_v);
                Q_EMIT _t->changed();
            }
            break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Kirigami::BasicThemeDefinition::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Kirigami__BasicThemeDefinition.data,
    qt_meta_data_Kirigami__BasicThemeDefinition,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Kirigami::BasicThemeDefinition::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kirigami::BasicThemeDefinition::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kirigami__BasicThemeDefinition.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kirigami::BasicThemeDefinition::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 52;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 52;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 52;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 52;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 52;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 52;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Kirigami::BasicThemeDefinition::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Kirigami::BasicThemeDefinition::sync(QQuickItem * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
struct qt_meta_stringdata_Kirigami__BasicThemeInstance_t {
    QByteArrayData data[1];
    char stringdata0[29];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kirigami__BasicThemeInstance_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kirigami__BasicThemeInstance_t qt_meta_stringdata_Kirigami__BasicThemeInstance = {
    {
QT_MOC_LITERAL(0, 0, 28) // "Kirigami::BasicThemeInstance"

    },
    "Kirigami::BasicThemeInstance"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kirigami__BasicThemeInstance[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void Kirigami::BasicThemeInstance::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Kirigami::BasicThemeInstance::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Kirigami__BasicThemeInstance.data,
    qt_meta_data_Kirigami__BasicThemeInstance,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Kirigami::BasicThemeInstance::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kirigami::BasicThemeInstance::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kirigami__BasicThemeInstance.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kirigami::BasicThemeInstance::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_Kirigami__BasicTheme_t {
    QByteArrayData data[1];
    char stringdata0[21];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kirigami__BasicTheme_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kirigami__BasicTheme_t qt_meta_stringdata_Kirigami__BasicTheme = {
    {
QT_MOC_LITERAL(0, 0, 20) // "Kirigami::BasicTheme"

    },
    "Kirigami::BasicTheme"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kirigami__BasicTheme[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void Kirigami::BasicTheme::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Kirigami::BasicTheme::staticMetaObject = { {
    QMetaObject::SuperData::link<PlatformTheme::staticMetaObject>(),
    qt_meta_stringdata_Kirigami__BasicTheme.data,
    qt_meta_data_Kirigami__BasicTheme,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Kirigami::BasicTheme::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kirigami::BasicTheme::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kirigami__BasicTheme.stringdata0))
        return static_cast<void*>(this);
    return PlatformTheme::qt_metacast(_clname);
}

int Kirigami::BasicTheme::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PlatformTheme::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
