/****************************************************************************
** Meta object code from reading C++ file 'imagecolors.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kirigami2-5.116.0/src/imagecolors.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'imagecolors.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ImageColors_t {
    QByteArrayData data[33];
    char stringdata0[575];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ImageColors_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ImageColors_t qt_meta_stringdata_ImageColors = {
    {
QT_MOC_LITERAL(0, 0, 11), // "ImageColors"
QT_MOC_LITERAL(1, 12, 13), // "sourceChanged"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 14), // "paletteChanged"
QT_MOC_LITERAL(4, 42, 22), // "fallbackPaletteChanged"
QT_MOC_LITERAL(5, 65, 32), // "fallbackPaletteBrightnessChanged"
QT_MOC_LITERAL(6, 98, 22), // "fallbackAverageChanged"
QT_MOC_LITERAL(7, 121, 23), // "fallbackDominantChanged"
QT_MOC_LITERAL(8, 145, 34), // "fallbackDominantContrastingCh..."
QT_MOC_LITERAL(9, 180, 24), // "fallbackHighlightChanged"
QT_MOC_LITERAL(10, 205, 25), // "fallbackForegroundChanged"
QT_MOC_LITERAL(11, 231, 25), // "fallbackBackgroundChanged"
QT_MOC_LITERAL(12, 257, 6), // "update"
QT_MOC_LITERAL(13, 264, 6), // "source"
QT_MOC_LITERAL(14, 271, 7), // "palette"
QT_MOC_LITERAL(15, 279, 17), // "paletteBrightness"
QT_MOC_LITERAL(16, 297, 22), // "ColorUtils::Brightness"
QT_MOC_LITERAL(17, 320, 7), // "average"
QT_MOC_LITERAL(18, 328, 8), // "dominant"
QT_MOC_LITERAL(19, 337, 16), // "dominantContrast"
QT_MOC_LITERAL(20, 354, 9), // "highlight"
QT_MOC_LITERAL(21, 364, 10), // "foreground"
QT_MOC_LITERAL(22, 375, 10), // "background"
QT_MOC_LITERAL(23, 386, 14), // "closestToWhite"
QT_MOC_LITERAL(24, 401, 14), // "closestToBlack"
QT_MOC_LITERAL(25, 416, 15), // "fallbackPalette"
QT_MOC_LITERAL(26, 432, 25), // "fallbackPaletteBrightness"
QT_MOC_LITERAL(27, 458, 15), // "fallbackAverage"
QT_MOC_LITERAL(28, 474, 16), // "fallbackDominant"
QT_MOC_LITERAL(29, 491, 27), // "fallbackDominantContrasting"
QT_MOC_LITERAL(30, 519, 17), // "fallbackHighlight"
QT_MOC_LITERAL(31, 537, 18), // "fallbackForeground"
QT_MOC_LITERAL(32, 556, 18) // "fallbackBackground"

    },
    "ImageColors\0sourceChanged\0\0paletteChanged\0"
    "fallbackPaletteChanged\0"
    "fallbackPaletteBrightnessChanged\0"
    "fallbackAverageChanged\0fallbackDominantChanged\0"
    "fallbackDominantContrastingChanged\0"
    "fallbackHighlightChanged\0"
    "fallbackForegroundChanged\0"
    "fallbackBackgroundChanged\0update\0"
    "source\0palette\0paletteBrightness\0"
    "ColorUtils::Brightness\0average\0dominant\0"
    "dominantContrast\0highlight\0foreground\0"
    "background\0closestToWhite\0closestToBlack\0"
    "fallbackPalette\0fallbackPaletteBrightness\0"
    "fallbackAverage\0fallbackDominant\0"
    "fallbackDominantContrasting\0"
    "fallbackHighlight\0fallbackForeground\0"
    "fallbackBackground"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ImageColors[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
      19,   80, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      10,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   69,    2, 0x06 /* Public */,
       3,    0,   70,    2, 0x06 /* Public */,
       4,    0,   71,    2, 0x06 /* Public */,
       5,    0,   72,    2, 0x06 /* Public */,
       6,    0,   73,    2, 0x06 /* Public */,
       7,    0,   74,    2, 0x06 /* Public */,
       8,    0,   75,    2, 0x06 /* Public */,
       9,    0,   76,    2, 0x06 /* Public */,
      10,    0,   77,    2, 0x06 /* Public */,
      11,    0,   78,    2, 0x06 /* Public */,

 // methods: name, argc, parameters, tag, flags
      12,    0,   79,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // methods: parameters
    QMetaType::Void,

 // properties: name, type, flags
      13, QMetaType::QVariant, 0x00495103,
      14, QMetaType::QVariantList, 0x00495001,
      15, 0x80000000 | 16, 0x00495009,
      17, QMetaType::QColor, 0x00495001,
      18, QMetaType::QColor, 0x00495001,
      19, QMetaType::QColor, 0x00495001,
      20, QMetaType::QColor, 0x00495001,
      21, QMetaType::QColor, 0x00495001,
      22, QMetaType::QColor, 0x00495001,
      23, QMetaType::QColor, 0x00495001,
      24, QMetaType::QColor, 0x00495001,
      25, QMetaType::QVariantList, 0x00495003,
      26, 0x80000000 | 16, 0x0049500b,
      27, QMetaType::QColor, 0x00495003,
      28, QMetaType::QColor, 0x00495003,
      29, QMetaType::QColor, 0x00495003,
      30, QMetaType::QColor, 0x00495003,
      31, QMetaType::QColor, 0x00495003,
      32, QMetaType::QColor, 0x00495003,

 // properties: notify_signal_id
       0,
       1,
       1,
       1,
       1,
       1,
       1,
       1,
       1,
       1,
       1,
       2,
       3,
       4,
       5,
       6,
       7,
       8,
       9,

       0        // eod
};

void ImageColors::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ImageColors *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->sourceChanged(); break;
        case 1: _t->paletteChanged(); break;
        case 2: _t->fallbackPaletteChanged(); break;
        case 3: _t->fallbackPaletteBrightnessChanged(); break;
        case 4: _t->fallbackAverageChanged(); break;
        case 5: _t->fallbackDominantChanged(); break;
        case 6: _t->fallbackDominantContrastingChanged(); break;
        case 7: _t->fallbackHighlightChanged(); break;
        case 8: _t->fallbackForegroundChanged(); break;
        case 9: _t->fallbackBackgroundChanged(); break;
        case 10: _t->update(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ImageColors::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageColors::sourceChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (ImageColors::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageColors::paletteChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (ImageColors::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageColors::fallbackPaletteChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (ImageColors::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageColors::fallbackPaletteBrightnessChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (ImageColors::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageColors::fallbackAverageChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (ImageColors::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageColors::fallbackDominantChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (ImageColors::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageColors::fallbackDominantContrastingChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (ImageColors::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageColors::fallbackHighlightChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (ImageColors::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageColors::fallbackForegroundChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (ImageColors::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ImageColors::fallbackBackgroundChanged)) {
                *result = 9;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<ImageColors *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QVariant*>(_v) = _t->source(); break;
        case 1: *reinterpret_cast< QVariantList*>(_v) = _t->palette(); break;
        case 2: *reinterpret_cast< ColorUtils::Brightness*>(_v) = _t->paletteBrightness(); break;
        case 3: *reinterpret_cast< QColor*>(_v) = _t->average(); break;
        case 4: *reinterpret_cast< QColor*>(_v) = _t->dominant(); break;
        case 5: *reinterpret_cast< QColor*>(_v) = _t->dominantContrast(); break;
        case 6: *reinterpret_cast< QColor*>(_v) = _t->highlight(); break;
        case 7: *reinterpret_cast< QColor*>(_v) = _t->foreground(); break;
        case 8: *reinterpret_cast< QColor*>(_v) = _t->background(); break;
        case 9: *reinterpret_cast< QColor*>(_v) = _t->closestToWhite(); break;
        case 10: *reinterpret_cast< QColor*>(_v) = _t->closestToBlack(); break;
        case 11: *reinterpret_cast< QVariantList*>(_v) = _t->m_fallbackPalette; break;
        case 12: *reinterpret_cast< ColorUtils::Brightness*>(_v) = _t->m_fallbackPaletteBrightness; break;
        case 13: *reinterpret_cast< QColor*>(_v) = _t->m_fallbackAverage; break;
        case 14: *reinterpret_cast< QColor*>(_v) = _t->m_fallbackDominant; break;
        case 15: *reinterpret_cast< QColor*>(_v) = _t->m_fallbackDominantContrasting; break;
        case 16: *reinterpret_cast< QColor*>(_v) = _t->m_fallbackHighlight; break;
        case 17: *reinterpret_cast< QColor*>(_v) = _t->m_fallbackForeground; break;
        case 18: *reinterpret_cast< QColor*>(_v) = _t->m_fallbackBackground; break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<ImageColors *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSource(*reinterpret_cast< QVariant*>(_v)); break;
        case 11:
            if (_t->m_fallbackPalette != *reinterpret_cast< QVariantList*>(_v)) {
                _t->m_fallbackPalette = *reinterpret_cast< QVariantList*>(_v);
                Q_EMIT _t->fallbackPaletteChanged();
            }
            break;
        case 12:
            if (_t->m_fallbackPaletteBrightness != *reinterpret_cast< ColorUtils::Brightness*>(_v)) {
                _t->m_fallbackPaletteBrightness = *reinterpret_cast< ColorUtils::Brightness*>(_v);
                Q_EMIT _t->fallbackPaletteBrightnessChanged();
            }
            break;
        case 13:
            if (_t->m_fallbackAverage != *reinterpret_cast< QColor*>(_v)) {
                _t->m_fallbackAverage = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->fallbackAverageChanged();
            }
            break;
        case 14:
            if (_t->m_fallbackDominant != *reinterpret_cast< QColor*>(_v)) {
                _t->m_fallbackDominant = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->fallbackDominantChanged();
            }
            break;
        case 15:
            if (_t->m_fallbackDominantContrasting != *reinterpret_cast< QColor*>(_v)) {
                _t->m_fallbackDominantContrasting = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->fallbackDominantContrastingChanged();
            }
            break;
        case 16:
            if (_t->m_fallbackHighlight != *reinterpret_cast< QColor*>(_v)) {
                _t->m_fallbackHighlight = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->fallbackHighlightChanged();
            }
            break;
        case 17:
            if (_t->m_fallbackForeground != *reinterpret_cast< QColor*>(_v)) {
                _t->m_fallbackForeground = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->fallbackForegroundChanged();
            }
            break;
        case 18:
            if (_t->m_fallbackBackground != *reinterpret_cast< QColor*>(_v)) {
                _t->m_fallbackBackground = *reinterpret_cast< QColor*>(_v);
                Q_EMIT _t->fallbackBackgroundChanged();
            }
            break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_a;
}

static const QMetaObject::SuperData qt_meta_extradata_ImageColors[] = {
    QMetaObject::SuperData::link<ColorUtils::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject ImageColors::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_ImageColors.data,
    qt_meta_data_ImageColors,
    qt_static_metacall,
    qt_meta_extradata_ImageColors,
    nullptr
} };


const QMetaObject *ImageColors::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ImageColors::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ImageColors.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ImageColors::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 19;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void ImageColors::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ImageColors::paletteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ImageColors::fallbackPaletteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ImageColors::fallbackPaletteBrightnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ImageColors::fallbackAverageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ImageColors::fallbackDominantChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ImageColors::fallbackDominantContrastingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ImageColors::fallbackHighlightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ImageColors::fallbackForegroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ImageColors::fallbackBackgroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
